summaryrefslogtreecommitdiff
path: root/MdeModulePkg/Universal
diff options
context:
space:
mode:
authorxli24 <xli24@6f19259b-4bc3-4df7-8a09-765794883524>2009-01-23 10:01:51 +0000
committerxli24 <xli24@6f19259b-4bc3-4df7-8a09-765794883524>2009-01-23 10:01:51 +0000
commit7772b1760f01d8be0c8d2fa16fd68db653ee89de (patch)
tree722f4319c7f1e014ed9b9f67b6acb733f49f8788 /MdeModulePkg/Universal
parent75a3814159d12dfa1b0f44670871e856bc57cb37 (diff)
downloadedk2-7772b1760f01d8be0c8d2fa16fd68db653ee89de.zip
edk2-7772b1760f01d8be0c8d2fa16fd68db653ee89de.tar.gz
edk2-7772b1760f01d8be0c8d2fa16fd68db653ee89de.tar.bz2
Update for Meta data.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@7361 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdeModulePkg/Universal')
-rw-r--r--MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatform.c16
-rw-r--r--MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatformDxe.inf36
-rw-r--r--MdeModulePkg/Universal/MemoryTest/BaseMemoryTestPei/BaseMemoryTestPei.inf4
-rw-r--r--MdeModulePkg/Universal/MemoryTest/NullMemoryTestDxe/NullMemoryTestDxe.inf2
-rw-r--r--MdeModulePkg/Universal/Metronome/Metronome.inf15
-rw-r--r--MdeModulePkg/Universal/MonotonicCounterRuntimeDxe/MonotonicCounterRuntimeDxe.inf10
-rw-r--r--MdeModulePkg/Universal/WatchdogTimerDxe/WatchdogTimer.inf11
7 files changed, 71 insertions, 23 deletions
diff --git a/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatformDxe.inf b/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatformDxe.inf
index be3a5f9..a96a633 100644
--- a/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatformDxe.inf
+++ b/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatformDxe.inf
@@ -1,5 +1,6 @@
#/** @file
-# Console Platfrom DXE Driver, install Console protocols and updates environment variables.
+# Console Platfrom DXE Driver that specifies whether device can be used as console
+# input/output device or error output device and update global variables accordingly.
#
# Copyright (c) 2006 - 2008, Intel Corporation
#
@@ -54,14 +55,37 @@
DebugLib
[Guids]
- gEfiGlobalVariableGuid ## SOMETIMES_CONSUMES ## Variable:L"ErrOut"
- gEfiStandardErrorDeviceGuid
- gEfiConsoleOutDeviceGuid
- gEfiConsoleInDeviceGuid
+ ##
+ # This is the VendorGuid of all architecturally defined variables in UEFI spec.
+ #
+ gEfiGlobalVariableGuid ## CONSUMES ## Variable:L"ConIn"
+ gEfiGlobalVariableGuid ## CONSUMES ## Variable:L"ConOut"
+ gEfiGlobalVariableGuid ## CONSUMES ## Variable:L"ErrOut"
+ gEfiGlobalVariableGuid ## CONSUMES ## Variable:L"ConInDev"
+ gEfiGlobalVariableGuid ## CONSUMES ## Variable:L"ConOutDev"
+ gEfiGlobalVariableGuid ## CONSUMES ## Variable:L"ErrOutDev"
+ ##
+ # This GUID is used to specify the device is the standard error device.
+ # If the device is a standard error device, this GUID as the protocol GUID will be installed
+ # onto this device handle.
+ #
+ gEfiStandardErrorDeviceGuid ## PROTOCOL
+ ##
+ # This GUID is used to specify the device is the console output device.
+ # If the device is a console output device, this GUID as the protocol GUID will be installed
+ # onto this device handle.
+ #
+ gEfiConsoleOutDeviceGuid ## PROTOCOL
+ ##
+ # This GUID is used to specify the device is the console input device.
+ # If the device is a console input device, this GUID as the protocol GUID will be installed
+ # onto this device handle.
+ #
+ gEfiConsoleInDeviceGuid ## PROTOCOL
[Protocols]
gEfiDevicePathProtocolGuid ## TO_START
gEfiSimpleTextInProtocolGuid ## TO_START
gEfiSimpleTextOutProtocolGuid ## TO_START
- gEfiHotPlugDeviceGuid ## SOMETIMES_CONSUMES
+ gEfiHotPlugDeviceGuid ## SOMETIMES_CONSUMES (Used to check if it's a hot-plug device)
\ No newline at end of file
diff --git a/MdeModulePkg/Universal/MemoryTest/BaseMemoryTestPei/BaseMemoryTestPei.inf b/MdeModulePkg/Universal/MemoryTest/BaseMemoryTestPei/BaseMemoryTestPei.inf
index 3e9800b..a2918bb 100644
--- a/MdeModulePkg/Universal/MemoryTest/BaseMemoryTestPei/BaseMemoryTestPei.inf
+++ b/MdeModulePkg/Universal/MemoryTest/BaseMemoryTestPei/BaseMemoryTestPei.inf
@@ -1,5 +1,5 @@
#/** @file
-# This PEIM provides memory test PPI for memory test in PEI Phase.
+# This PEIM provides Base Memory Test PPI for memory test in PEI Phase.
#
# Copyright (c) 2006 - 2008, Intel Corporation. <BR>
# All rights reserved. This program and the accompanying materials
@@ -41,7 +41,7 @@
PeiServicesLib
[Ppis]
- gPeiBaseMemoryTestPpiGuid # PPI ALWAYS_PRODUCED
+ gPeiBaseMemoryTestPpiGuid ## PRODUCES
[FixedPcd.common]
gEfiMdePkgTokenSpaceGuid.PcdStatusCodeValueMemoryTestStarted
diff --git a/MdeModulePkg/Universal/MemoryTest/NullMemoryTestDxe/NullMemoryTestDxe.inf b/MdeModulePkg/Universal/MemoryTest/NullMemoryTestDxe/NullMemoryTestDxe.inf
index 5a951f2..c030ef5 100644
--- a/MdeModulePkg/Universal/MemoryTest/NullMemoryTestDxe/NullMemoryTestDxe.inf
+++ b/MdeModulePkg/Universal/MemoryTest/NullMemoryTestDxe/NullMemoryTestDxe.inf
@@ -42,7 +42,7 @@
DebugLib
[Protocols]
- gEfiGenericMemTestProtocolGuid # PROTOCOL ALWAYS_PRODUCED
+ gEfiGenericMemTestProtocolGuid ## PRODUCES
[Depex]
TRUE
diff --git a/MdeModulePkg/Universal/Metronome/Metronome.inf b/MdeModulePkg/Universal/Metronome/Metronome.inf
index 5dc6227..3315001 100644
--- a/MdeModulePkg/Universal/Metronome/Metronome.inf
+++ b/MdeModulePkg/Universal/Metronome/Metronome.inf
@@ -1,6 +1,15 @@
#/** @file
-# This module produces the Metronome Architectural Protocol on top of an instance
-# of the Timer Library defined in the MdePkg.
+# This module produces the Metronome Architectural Protocol on top of Timer Library.
+#
+# This is a generic implementation of the Metronome Architectural Protocol that
+# layers on top of an instance of the Timer Library. The Timer Library provides
+# functions for nanosecond and microsecond delays. This generic implementation
+# produces a fixed TickPeriod of 100ns unit, and when the WaitForTick() service
+# is called, the number of ticks passed in is converted to either nanosecond or
+# microsecond units. If the number of ticks is small, then nanoseconds are used.
+# If the number of ticks is large, then microseconds are used. This prevents
+# overflows that could occur for long delays if only nanoseconds were used and also
+# provides the greatest accuracy for small delays.
#
# Copyright (c) 2008, Intel Corporation
# All rights reserved. This program and the accompanying materials
@@ -41,7 +50,7 @@
Metronome.h
[Protocols]
- gEfiMetronomeArchProtocolGuid
+ gEfiMetronomeArchProtocolGuid ## PRODUCES
[Depex]
TRUE
diff --git a/MdeModulePkg/Universal/MonotonicCounterRuntimeDxe/MonotonicCounterRuntimeDxe.inf b/MdeModulePkg/Universal/MonotonicCounterRuntimeDxe/MonotonicCounterRuntimeDxe.inf
index 362ca98..180067d 100644
--- a/MdeModulePkg/Universal/MonotonicCounterRuntimeDxe/MonotonicCounterRuntimeDxe.inf
+++ b/MdeModulePkg/Universal/MonotonicCounterRuntimeDxe/MonotonicCounterRuntimeDxe.inf
@@ -46,9 +46,17 @@
[Protocols]
- gEfiMonotonicCounterArchProtocolGuid # PROTOCOL ALWAYS_PRODUCED
+ gEfiMonotonicCounterArchProtocolGuid ## PRODUCES
[Depex]
gEfiVariableArchProtocolGuid AND gEfiVariableWriteArchProtocolGuid
+
+# [Event]
+# ##
+# # This is a private event to update the Monotonic Counter's high part when low part overflows.
+# #
+# EVT_NOTIFY_SIGNAL ## PRODUCES
+#
+# \ No newline at end of file
diff --git a/MdeModulePkg/Universal/WatchdogTimerDxe/WatchdogTimer.inf b/MdeModulePkg/Universal/WatchdogTimerDxe/WatchdogTimer.inf
index e00acac..2eb24e3 100644
--- a/MdeModulePkg/Universal/WatchdogTimerDxe/WatchdogTimer.inf
+++ b/MdeModulePkg/Universal/WatchdogTimerDxe/WatchdogTimer.inf
@@ -40,9 +40,10 @@
ReportStatusCodeLib
UefiDriverEntryPoint
DebugLib
+ PcdLib
[Protocols]
- gEfiWatchdogTimerArchProtocolGuid # PROTOCOL ALWAYS_PRODUCED
+ gEfiWatchdogTimerArchProtocolGuid ## PRODUCES
[FixedPcd.common]
gEfiMdePkgTokenSpaceGuid.PcdStatusCodeValueEfiWatchDogTimerExpired
@@ -50,4 +51,10 @@
[depex]
gEfiTimerArchProtocolGuid
- \ No newline at end of file
+# [Event]
+# ##
+# # Relative timer event set by EFI_WATCHDOG_TIMER_ARCH_PROTOCOL.SetTimerPeriod()
+# #
+# EVENT_TYPE_RELATIVE_TIMER ## PRODUCES
+#
+# \ No newline at end of file
diff --git a/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatform.c b/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatform.c
index 3ba28c8..f3aa4a4 100644
--- a/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatform.c
+++ b/MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatform.c
@@ -317,7 +317,7 @@ ConPlatformTextInDriverBindingStart (
Device GUID on ControllerHandle.
If this devcie is not one hot-plug devce, append its device path into the
- console environment variables ConOutDev, StdErrDev.
+ console environment variables ConOutDev, ErrOutDev.
@param This Protocol instance pointer.
@param ControllerHandle Handle of device to bind driver to
@@ -374,7 +374,7 @@ ConPlatformTextOutDriverBindingStart (
}
//
// Check the device handle, if it is a hot plug device,
// do not put the device path into ConOutDev and StdErrDev,
// and install gEfiConsoleOutDeviceGuid to the device handle directly.
// The policy is, make hot plug device plug in and play immediately.
//
@@ -396,7 +396,7 @@ ConPlatformTextOutDriverBindingStart (
APPEND
);
//
// Then append the device path to the StdErrDev environment variable
//
ConPlatformUpdateDeviceVariable (
L"ErrOutDev",
@@ -424,7 +424,7 @@ ConPlatformTextOutDriverBindingStart (
);
}
//
// If the device path is successfully added to the StdErr environment variable,
// then install EfiStandardErrorDeviceGuid onto ControllerHandle
//
Status = ConPlatformUpdateDeviceVariable (
@@ -557,7 +557,7 @@ ConPlatformTextOutDriverBindingStop (
EFI_DEVICE_PATH_PROTOCOL *DevicePath;
//
// If it is not a hot-plug device, first delete it from the ConOutDev and StdErrDev variable.
//
if (!IsHotPlugDevice (This->DriverBindingHandle, ControllerHandle)) {
//
@@ -573,7 +573,7 @@ ConPlatformTextOutDriverBindingStop (
);
if (!EFI_ERROR (Status)) {
//
// Remove DevicePath from ConOutDev, and StdErrDev
//
ConPlatformUpdateDeviceVariable (
L"ConOutDev",
@@ -655,7 +655,7 @@ ConPlatformUnInstallProtocol (
}
/**
- Get the necessary size of buffer and read the variabe.
+ Get the necessary size of buffer and read the variable.
First get the necessary size of buffer. Then read the
EFI variable (Name) and return a dynamically allocated
@@ -824,7 +824,7 @@ ConPlatformMatchDevicePaths (
Update console environment variables.
@param VariableName Console environment variables, ConOutDev, ConInDev
- StdErrDev, ConIn or ConOut.
+ ErrOutDev, ConIn ,ConOut or ErrOut.
@param DevicePath Console devcie's device path.
@param Operation Variable operations, including APPEND, CHECK and DELETE.
@@ -374,7 +374,7 @@ ConPlatformTextOutDriverBindingStart (
//
// Check the device handle, if it is a hot plug device,
- // do not put the device path into ConOutDev and StdErrDev,
+ // do not put the device path into ConOutDev and ErrOutDev,
// and install gEfiConsoleOutDeviceGuid to the device handle directly.
// The policy is, make hot plug device plug in and play immediately.
@@ -396,7 +396,7 @@ ConPlatformTextOutDriverBindingStart (
);
//
- // Then append the device path to the StdErrDev environment variable
+ // Then append the device path to the ErrOutDev environment variable
//
ConPlatformUpdateDeviceVariable (
@@ -424,7 +424,7 @@ ConPlatformTextOutDriverBindingStart (
}
//
- // If the device path is successfully added to the StdErr environment variable,
+ // If the device path is successfully added to the ErrOut environment variable,
// then install EfiStandardErrorDeviceGuid onto ControllerHandle
//
@@ -557,7 +557,7 @@ ConPlatformTextOutDriverBindingStop (
EFI_DEVICE_PATH_PROTOCOL *DevicePath;
//
- // If it is not a hot-plug device, first delete it from the ConOutDev and StdErrDev variable.
+ // If it is not a hot-plug device, first delete it from the ConOutDev and ErrOutDev variable.
//
if (!IsHotPlugDevice (This->DriverBindingHandle, ControllerHandle)) {
@@ -573,7 +573,7 @@ ConPlatformTextOutDriverBindingStop (
if (!EFI_ERROR (Status)) {
//
- // Remove DevicePath from ConOutDev, and StdErrDev
+ // Remove DevicePath from ConOutDev, and ErrOutDev
//
ConPlatformUpdateDeviceVariable (